@@ -47,7 +47,7 @@ def _strip_extras(path: str) -> tuple[str, str | None]:
     m = re.match(r"^(.+)(\[[^\]]+\])$", path)
     extras = None
     if m:
-        path_no_extras = m.group(1)
+        path_no_extras = m.group(1).rstrip()
         extras = m.group(2)
     else:
         path_no_extras = path
@@ -86,17 +86,25 @@ def _set_requirement_extras(req: Requirement, new_extras: set[str]) -> Requireme
     return get_requirement(f"{pre}{extras}{post}")
 
 
-def parse_editable(editable_req: str) -> tuple[str | None, str, set[str]]:
-    """Parses an editable requirement into:
-        - a requirement name
-        - an URL
-        - extras
-        - editable options
-    Accepted requirements:
-        svn+http://blahblah@rev#egg=Foobar[baz]&subdirectory=version_subdir
-        .[some_extra]
-    """
+def _parse_direct_url_editable(editable_req: str) -> tuple[str | None, str, set[str]]:
+    try:
+        req = Requirement(editable_req)
+    except InvalidRequirement:
+        pass
+    else:
+        if req.url:
+            # Join the marker back into the name part. This will be parsed out
+            # later into a Requirement again.
+            if req.marker:
+                name = f"{req.name} ; {req.marker}"
+            else:
+                name = req.name
+            return (name, req.url, req.extras)
 
+    raise ValueError
+
+
+def _parse_pip_syntax_editable(editable_req: str) -> tuple[str | None, str, set[str]]:
     url = editable_req
 
     # If a file path is specified with extras, strip off the extras.
@@ -122,9 +130,27 @@ def parse_editable(editable_req: str) -> tuple[str | None, str, set[str]]:
             url = f"{version_control}+{url}"
             break
 
+    return Link(url).egg_fragment, url, set()
+
+
+def parse_editable(editable_req: str) -> tuple[str | None, str, set[str]]:
+    """Parses an editable requirement into:
+        - a requirement name with environment markers
+        - an URL
+        - extras
+    Accepted requirements:
+        - svn+http://blahblah@rev#egg=Foobar[baz]&subdirectory=version_subdir
+        - local_path[some_extra]
+        - Foobar[extra] @ svn+http://blahblah@rev#subdirectory=subdir ; markers
+    """
+    try:
+        package_name, url, extras = _parse_direct_url_editable(editable_req)
+    except ValueError:
+        package_name, url, extras = _parse_pip_syntax_editable(editable_req)
+
     link = Link(url)
 
-    if not link.is_vcs:
+    if not link.is_vcs and not link.url.startswith("file:"):
         backends = ", ".join(vcs.all_schemes)
         raise InstallationError(
             f"{editable_req} is not a valid editable requirement. "
@@ -132,13 +158,13 @@ def parse_editable(editable_req: str) -> tuple[str | None, str, set[str]]:
             f"(beginning with {backends})."
         )
 
-    package_name = link.egg_fragment
-    if not package_name:
+    # The project name can be inferred from local file URIs easily.
+    if not package_name and not link.url.startswith("file:"):
         raise InstallationError(
             f"Could not detect requirement name for '{editable_req}', "
-            "please specify one with #egg=your_package_name"
+            "please specify one with your_package_name @ URL"
         )
-    return package_name, url, set()
+    return package_name, url, extras
 
 
 def check_first_requirement_in_file(filename: str) -> None:
@@ -225,9 +251,7 @@ def install_req_from_editable(
     editable_req: str,
     comes_from: InstallRequirement | str | None = None,
     *,
-    use_pep517: bool | None = None,
     isolated: bool = False,
-    global_options: list[str] | None = None,
     hash_options: dict[str, list[str]] | None = None,
     constraint: bool = False,
     user_supplied: bool = False,
@@ -244,9 +268,7 @@ def install_req_from_editable(
         permit_editable_wheels=permit_editable_wheels,
         link=parts.link,
         constraint=constraint,
-        use_pep517=use_pep517,
         isolated=isolated,
-        global_options=global_options,
         hash_options=hash_options,
         config_settings=config_settings,
         extras=parts.extras,
@@ -389,9 +411,7 @@ def install_req_from_line(
     name: str,
     comes_from: str | InstallRequirement | None = None,
     *,
-    use_pep517: bool | None = None,
     isolated: bool = False,
-    global_options: list[str] | None = None,
     hash_options: dict[str, list[str]] | None = None,
     constraint: bool = False,
     line_source: str | None = None,
@@ -411,9 +431,7 @@ def install_req_from_line(
         comes_from,
         link=parts.link,
         markers=parts.markers,
-        use_pep517=use_pep517,
         isolated=isolated,
-        global_options=global_options,
         hash_options=hash_options,
         config_settings=config_settings,
         constraint=constraint,
@@ -426,7 +444,6 @@ def install_req_from_req_string(
     req_string: str,
     comes_from: InstallRequirement | None = None,
     isolated: bool = False,
-    use_pep517: bool | None = None,
     user_supplied: bool = False,
 ) -> InstallRequirement:
     try:
@@ -455,7 +472,6 @@ def install_req_from_req_string(
         req,
         comes_from,
         isolated=isolated,
-        use_pep517=use_pep517,
         user_supplied=user_supplied,
     )
 
@@ -463,7 +479,6 @@ def install_req_from_req_string(
 def install_req_from_parsed_requirement(
     parsed_req: ParsedRequirement,
     isolated: bool = False,
-    use_pep517: bool | None = None,
     user_supplied: bool = False,
     config_settings: dict[str, str | list[str]] | None = None,
 ) -> InstallRequirement:
@@ -471,7 +486,6 @@ def install_req_from_parsed_requirement(
         req = install_req_from_editable(
             parsed_req.requirement,
             comes_from=parsed_req.comes_from,
-            use_pep517=use_pep517,
             constraint=parsed_req.constraint,
             isolated=isolated,
             user_supplied=user_supplied,
@@ -482,13 +496,7 @@ def install_req_from_parsed_requirement(
         req = install_req_from_line(
             parsed_req.requirement,
             comes_from=parsed_req.comes_from,
-            use_pep517=use_pep517,
             isolated=isolated,
-            global_options=(
-                parsed_req.options.get("global_options", [])
-                if parsed_req.options
-                else []
-            ),
             hash_options=(
                 parsed_req.options.get("hashes", {}) if parsed_req.options else {}
             ),
@@ -509,9 +517,7 @@ def install_req_from_link_and_ireq(
         editable=ireq.editable,
         link=link,
         markers=ireq.markers,
-        use_pep517=ireq.use_pep517,
         isolated=ireq.isolated,
-        global_options=ireq.global_options,
         hash_options=ireq.hash_options,
         config_settings=ireq.config_settings,
         user_supplied=ireq.user_supplied,
@@ -532,9 +538,7 @@ def install_req_drop_extras(ireq: InstallRequirement) -> InstallRequirement:
         editable=ireq.editable,
         link=ireq.link,
         markers=ireq.markers,
-        use_pep517=ireq.use_pep517,
         isolated=ireq.isolated,
-        global_options=ireq.global_options,
         hash_options=ireq.hash_options,
         constraint=ireq.constraint,
         extras=[],
